# 27 Apr 12
# 	R script that reads merged climate/conflict data & estimates additional regression models
#
#	This file is in support of the publication:
#		OLoughlin, J., F. Witmer, A. Linke, A. Laing, A Gettelman, and J. Dudhia (2012).
#		Climate variability and conflict risk in East Africa 1990-2009.
#		Proceedings of the National Academy of Sciences.
#
#		PNAS Table S4, col. b, e-g and Figs S9 b, e-g and S10 b, e-g
#		PNAS Table S5, cols. a-f and Figs S11 a-f and S12 a-f
#		PNAS Table S6 & Figs S11g and S12g
###############################################

# set output directory
outDir <- "C://Users/XXX/"

# load model analsys functions
source(paste(outDir, "../SharedClimateModelFunctions.R", sep=""))

# load grid-month data & define regression variables for analysis
source(paste(outDir, "../LoadOneDegGridMonthData.R", sep=""))

#### ACLED logit model
#	PNAS Table S4, col. b and Figs S9b and S10b
modelName <- "BinLgt"
depVar <- "EventsBin"; precipVar <- "SPI6"; tempVar <- "TI6"
longData[[depVar]] <- (longData$Events >= 1) * 1
# convert sp-ti lag to binary also [though few differences when using full version]
longData[[paste(depVar, "SpLag_lag1", sep="")]] <- (longData[[paste("Events", "SpLag_lag1", sep="")]] > 0) * 1
gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(", precipVar,", bs=\"",baseSmooth,"\")", sep=""), paste("s(",tempVar,", bs=\"",baseSmooth,"\")", sep=""), controlVars)
gamLogitFE <- myGAM(depVar, gamVars, thetaNB=NULL, writeFile=TRUE, modelName, funcForm="logit")	# 79-100 sec

#### No controls, retain fixed effects & sp-ti lag
#	PNAS Table S4, col. e and Figs S9e and S10e
modelName <- "NoCntrlsWithSpLag"
depVar <- "Events"; precipVar <- "SPI6"; tempVar <- "TI6"
glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, "Country", "factor(Year)")
rev3_NB <- myGLM(depVar, glmVars, writeFile=TRUE, modelName)	# 42 secs

gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(", precipVar,", bs=\"",baseSmooth,"\")", sep=""), paste("s(",tempVar,", bs=\"",baseSmooth,"\")", sep=""), "Country", "factor(Year)")
thetaNB <- rev3_NB$theta
gamRevObj <- myGAM(depVar, gamVars, thetaNB, writeFile=TRUE, modelName)	# 83 secs

#### No sp-ti lag
#	PNAS Table S4, col. f and Figs S9f and S10f
modelName <- "NoSpTiLag"
depVar <- "Events"; precipVar <- "SPI6"; tempVar <- "TI6"
glmVars <- c(precipVar, tempVar, controlVars)
rev4_NB <- myGLM(depVar, glmVars, writeFile=TRUE, modelName)	# 40 secs

gamVars <- c(paste("s(", precipVar,", bs=\"",baseSmooth,"\")", sep=""), paste("s(",tempVar,", bs=\"",baseSmooth,"\")", sep=""), controlVars)
thetaNB <- rev4_NB$theta
gamRevObj <- myGAM(depVar, gamVars, thetaNB, writeFile=TRUE, modelName)	# 101 secs


#### add growing seasons
#	PNAS Table S4, col. g and Figs S9g and S10g
modelName <- "GrowSeason"
depVar <- "Events"; precipVar <- "SPI6"; tempVar <- "TI6"
glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars, "GrowSeason")
baseNB <- myGLM(depVar, glmVars, writeFile=TRUE, modelName)	# 44 secs

gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(SPI6, bs=\"",baseSmooth,"\")", sep=""), paste("s(TI6, bs=\"",baseSmooth,"\")", sep=""), controlVars, "GrowSeason")
thetaNB <- baseNB$theta
gamRevObj <- myGAM(depVar, gamVars, thetaNB, writeFile=TRUE, modelName)	# 136 secs [add to SI material]



#### Interaction terms
#	PNAS Table S5, cols. a-d and Figs S11 a-d and S12 a-d
#	SPI6 x Ethnic leader
#	TI6 x Ethnic leader
#	SPI6 x Pol'l rights
#	TI6 x Pol'l rights
modelName <- "SPI6_Ethnic"
interTerm <- "SPI6:Ethnologue"
depVar <- "Events"; precipVar <- "SPI6"; tempVar <- "TI6"
glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars, interTerm)
baseNB <- myGLM(depVar, glmVars, writeFile=TRUE, modelName)	# 46 secs
gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(SPI6, bs=\"",baseSmooth,"\")", sep=""), paste("s(TI6, bs=\"",baseSmooth,"\")", sep=""), controlVars, interTerm)
thetaNB <- baseNB$theta
gamRevObj <- myGAM(depVar, gamVars, thetaNB, writeFile=TRUE, modelName)	# 124 secs

modelName <- "SPI6_PolRights"
interTerm <- "SPI6:PR_lag12"
glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars, interTerm)
baseNB <- myGLM(depVar, glmVars, writeFile=TRUE, modelName)	# 45 secs
#vif(baseNB)	# problem w/ SPI6 & interTerm for this model
gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(SPI6, bs=\"",baseSmooth,"\")", sep=""), paste("s(TI6, bs=\"",baseSmooth,"\")", sep=""), controlVars, interTerm)
thetaNB <- baseNB$theta
gamRevObj <- myGAM(depVar, gamVars, thetaNB, writeFile=TRUE, modelName)	# 125 secs

# looks like only this version is significant --> but not when using clust. errors
modelName <- "TI6_Ethnic"
interTerm <- "TI6:Ethnologue"
glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars, interTerm)
baseNB <- myGLM(depVar, glmVars, writeFile=TRUE, modelName)	# 46 secs
gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(SPI6, bs=\"",baseSmooth,"\")", sep=""), paste("s(TI6, bs=\"",baseSmooth,"\")", sep=""), controlVars, interTerm)
thetaNB <- baseNB$theta
gamRevObj <- myGAM(depVar, gamVars, thetaNB, writeFile=TRUE, modelName)	# 130 secs

modelName <- "TI6_PolRights"
interTerm <- "TI6:PR_lag12"
glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars, interTerm)
baseNB <- myGLM(depVar, glmVars, writeFile=TRUE, modelName)	# 46 secs
#vif(baseNB)	# problem w/ TI6 & interTerm for this model
gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(SPI6, bs=\"",baseSmooth,"\")", sep=""), paste("s(TI6, bs=\"",baseSmooth,"\")", sep=""), controlVars, interTerm)
thetaNB <- baseNB$theta
gamRevObj <- myGAM(depVar, gamVars, thetaNB, writeFile=TRUE, modelName)	# 91 secs


#### run grid & year FE w/ & w/ out control variables using neg bin model
# 	PNAS Table S5, cols. e-f and Figs S11 e-f and S12 e-f
modelName <- "gridFE"
depVar <- "Events"; precipVar <- "SPI6"; tempVar <- "TI6"
glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars[-c(12)], "factor(Grid)"); glmVars
glmRevObj <- myGLM(depVar, glmVars, writeFile=TRUE, modelName)	# 2.4 hours

gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(", precipVar,", bs=\"",baseSmooth,"\")", sep=""), paste("s(",tempVar,", bs=\"",baseSmooth,"\")", sep=""), controlVars[-c(12)], "factor(Grid)"); gamVars
thetaNB <- glmRevObj$theta
gamRevObj <- myGAM(depVar, gamVars, thetaNB, writeFile=TRUE, modelName)	# 8 hours

# now w/ no controls
depVar <- "Events"; precipVar <- "SPI6"; tempVar <- "TI6"
modelName <- "gridFEnoControls"; glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, "factor(Year)", "factor(Grid)"); glmVars
glmRevObj <- myGLM(depVar, glmVars, writeFile=TRUE, modelName)	# 31 min on Wilbur

gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(", precipVar,", bs=\"",baseSmooth,"\")", sep=""), paste("s(",tempVar,", bs=\"",baseSmooth,"\")", sep=""), "factor(Year)", "factor(Grid)"); gamVars
thetaNB <- glmRevObj$theta
gamRevObj <- myGAM(depVar, gamVars, thetaNB, writeFile=TRUE, modelName)	# 18 hrs on Wilbur


#### OLS w/ grid & year fixed effects
#	PNAS Table S6 & Figs S11g and S12g

## a) glm model, no splines
depVar <- "Events"; precipVar <- "SPI6"; tempVar <- "TI6"
glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars[-c(12)], "factor(Grid)")
olsGridFE <- myGLM(depVar, glmVars, writeFile=TRUE, "olsbase", funcForm="ols")	# 128 secs


# run OLS grid FE non-GAM version w/ extreme vars: hot/cold, wet/dry
## SPI6 extremes variables
longData$SPI6_dry <- (longData$SPI6 <= -1) * 1; sum(longData$SPI6_dry)	# 10855
longData$SPI6_wet <- (longData$SPI6 >= 1) * 1; sum(longData$SPI6_wet)	# 11014

## b) SPI6 dry
precipVar <- "SPI6_dry"; tempVar <- "TI6"
glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars[-c(12)], "factor(Grid)")
SPI6_dryOLS <- myGLM(depVar, glmVars, writeFile=TRUE, "olsSPI6_dry", funcForm="ols")	# 124 secs

## c) SPI6 wet
precipVar <- "SPI6_wet"; tempVar <- "TI6"
glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars[-c(12)], "factor(Grid)")
SPI6_wetOLS <- myGLM(depVar, glmVars, writeFile=TRUE, "olsSPI6_wet", funcForm="ols")	# 124 secs

## TI6 extremes variables
longData$TI6_hot <- (longData$TI6 >= 1) * 1; sum(longData$TI6_hot)	# 22556 -> 31882 -> 32196
longData$TI6_cold <- (longData$TI6 <= -1) * 1; sum(longData$TI6_cold)	# 2476 -> 1611 -> 1588

## d) TI6_hot
precipVar <- "SPI6"; tempVar <- "TI6_hot"
glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars[-c(12)], "factor(Grid)")
TI6_hotOLS <- myGLM(depVar, glmVars, writeFile=TRUE, "olsTI6_hot", funcForm="ols")	# 123 secs

## e) TI6_cold
precipVar <- "SPI6"; tempVar <- "TI6_cold"
glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars[-c(12)], "factor(Grid)")
TI6_coldOLS <- myGLM(depVar, glmVars, writeFile=TRUE, "olsTI6_cold", funcForm="ols")	# 126 secs

## f) OLS GAM version w/ Grid FE
depVar <- "Events"; precipVar <- "SPI6"; tempVar <- "TI6"
# lm() is the same as glm(family=gaussian()), so run GAM w/ gaussian
gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(", precipVar,", bs=\"",baseSmooth,"\")", sep=""), paste("s(",tempVar,", bs=\"",baseSmooth,"\")", sep=""), controlVars[-c(12)], "factor(Grid)"); gamVars
gamGridFE <- myGAM(depVar, gamVars, writeFile=TRUE, modelName="olsGAM", funcForm="ols")	# 258 sec

