# 11 May 11
# 	R script that reads merged climate/conflict data & estimates regression models
#		uses full violent event count data/cell
#		estimates models for each country subset
# 14 Nov 11
#	Revised to use the 'Country' variable defined in countryMnth.csv
#
#	This file is in support of the publication:
#		OLoughlin, J., F. Witmer, A. Linke, A. Laing, A Gettelman, and J. Dudhia (2012).
#		Climate variability and conflict risk in East Africa 1990-2009.
#		Proceedings of the National Academy of Sciences.
#
#		PNAS Table S2 and Figs S5 and S6
###############################################

# set output directory
outDir <- "C://Users/XXX/"

# load model analsys functions
source(paste(outDir, "../SharedClimateModelFunctions.R", sep=""))

# load grid-month data & define regression variables for analysis
source(paste(outDir, "../LoadOneDegGridMonthData.R", sep=""))
	
##### generate list of indices for each country, estimate GAM models, write output to files
#cntryNames <- c("Burundi", "Djibouti", "Eritrea", "Ethiopia", "Kenya", "Rwanda", "Somalia", "Uganda")	# Tanzania takes ~15 min
cntryNames <- c("Burundi", "Djibouti", "Eritrea", "Ethiopia", "Kenya", "Rwanda", "Somalia", "Tanzania", "Uganda")

# takes ~2.6 minutes w/ variable theta & "cr", only a bit slower (3.2 min) w/ "tp"
startTime <- proc.time()
for(cntry in cntryNames) {	# cntry<-cntryNames[3]
	print(paste("starting", cntry, "...")); flush.console()
	cntryData <- longData[longData$Country == cntry, ]
	# tmp<-fix(cntryData)
	# summary(cntryData)
	# do not add Country as a contrast (categorical fixed effect) if there's only 1 country
	dropVarList <- c(12)	# drop "Country" FE 

	# drop Ethnologue for countries that show no variation in Ethnic leadership
	if (cntry %in% c("Burundi", "Rwanda", "Somalia")) {
		dropVarList <- c(dropVarList, 1)
	}
	# drop PR_lag12 for countries that have collinearity problems, or Intercept = 0 problems
	# forcing the model through the origin for models w/ Intercept = 0 reveals instability in PR_lag12 variable
	#vif(cntryGLM_NB)	# huge collinearity problem for PR_lag12, so drop it for Ethiopia
	if (cntry %in% c("Burundi", "Ethiopia", "Somalia", "Tanzania", "Uganda")) {
		dropVarList <- c(dropVarList, 6)
	}
	# drop ElecPres for countries that had no (or only one) pres. election
	if (cntry %in% c("Burundi", "Eritrea", "Ethiopia", "Rwanda")) {
		dropVarList <- c(dropVarList, 7)
	}
	# drop DistToRdLn
	if (cntry %in% c("Burundi")) {
		dropVarList <- c(dropVarList, 9)
	}
	
	#cor(cntryData[,controlVars[-c(dropVarList, 13)]])
	print(paste("dropping", paste(controlVars[dropVarList], collapse=", "), "for", cntry))

	# use glm to set theta for neg. bin. gam distribution
	glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars[-dropVarList])
	if (cntry == "Eritrea") {	# use quasipoisson to estimate theta for Eritrea (Tanzania now OK after dropping PR_lag12)
		glmText <- paste(depVar, " ~ ", paste(glmVars, "+ ", collapse=""), sep="")
		glmFormula <- as.formula(substr(glmText, 1, nchar(glmText)-2))
		modelQP <- glm(glmFormula, data=cntryData, family=quasipoisson())
		thetaNB <- theta.ml(modelQP$y, fitted(modelQP), limit=25)[1]
		thetaNB <- max(thetaNB, 0.04)	# set a minimum theta
		# could also set it to 0.17 since that's what it used to be
		# or set all all theta's to 0.12 since that's what the overall model is
		#	(but this does not reduce jitters in Somalia)
#		thetaNB <- 0.12
	} else {
		# best to let theta vary for each model (?)
		cntryGLM_NB <- myGLM(depVar, glmVars, writeFile=FALSE, dataFr=cntryData)
		thetaNB <- cntryGLM_NB$theta
	}
	# GVIF^(1/(2*Df)) > 2 means more than 2x a decrease in the precision of estimation due to collinearity
	#	confidence intervals twice as wide as they would be for uncorrelated predictors
	if (any(is.na(coef(cntryGLM_NB))))
		print("can't perform vif test due to model NAs")
	else
		print(vif(cntryGLM_NB)[vif(cntryGLM_NB)[,3] > 2, ])		# lots of collinearity problems remain
	print(paste("    theta =", thetaNB)); flush.console()

	gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(SPI6, bs=\"",baseSmooth,"\")", sep=""), paste("s(TI6, bs=\"",baseSmooth,"\")", sep=""), controlVars[-dropVarList])
	# WARNING: different thetas have a big effect on what the GAM plots look like
	cntryGAM <- myGAM(depVar, gamVars, thetaNB, writeFile=TRUE, modelName=cntry, dataFr=cntryData)
}
endTime <- proc.time()
print(paste("elapsed time: ", round(endTime[3]-startTime[3])/60, " minutes", sep=""))
