# 13 May 11
# 	R script that reads merged climate/conflict data & estimates regression models
#		uses full violent event count data/cell
#		estimates models for each 5-year subset
# 14 Nov 11
#	revised to use the 'Country' variable defined in countryMnth.csv
#
#	This file is in support of the publication:
#		OLoughlin, J., F. Witmer, A. Linke, A. Laing, A Gettelman, and J. Dudhia (2012).
#		Climate variability and conflict risk in East Africa 1990-2009.
#		Proceedings of the National Academy of Sciences.
#
#		PNAS Table S3, cols a-d and Figs S7 a-d and S8 a-d
###############################################

# set output directory
outDir <- "C://Users/XXX/"

# load model analsys functions
source(paste(outDir, "../SharedClimateModelFunctions.R", sep=""))

# load grid-month data & define regression variables for analysis
source(paste(outDir, "../LoadOneDegGridMonthData.R", sep=""))

##### generate list of indices for each year, estimate GAM models, write output to files
glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars)

gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(SPI6, bs=\"",baseSmooth,"\")", sep=""), paste("s(TI6, bs=\"",baseSmooth,"\")", sep=""), controlVars)


# define 5-yr periods
per1 <- c(1991:1994)	# only 4 years for per1
per2 <- c(1995:1999)
per3 <- c(2000:2004)
per4 <- c(2005:2009)
fiveYrPeriods <- list(per1, per2, per3, per4) # fiveYrPeriods <- list(per2, per3, per4)

#### extract rows for each 5-year period
# split rowID field to get year
rowSplit <- strsplit(longData$rowID, "\\.")
yrMnth<-sapply(1:length(rowSplit), function(x) rowSplit[[x]][2])
longYrs<-trunc(as.numeric(yrMnth)/100)
#longYrs[80000:80100]

# takes 7.3 minutes w/ variable theta -> 5.1 min -> 13.5 min
startTime <- proc.time()
fiveYrGAMs <- list()
for(i in 1:length(fiveYrPeriods)) {	# i<-2
	print(paste("starting", paste(fiveYrPeriods[[i]], collapse=", "), "...")); flush.console()
	longRows <- longYrs %in% fiveYrPeriods[[i]]	# match longYrs to 5-yr period
	
	fiveYrData <- longData[longRows, ]
	# tmp<-fix(fiveYrData)
	# best to let theta vary for each model
	fiveYrGLM_NB <- myGLM(depVar, glmVars, writeFile=FALSE, dataFr=fiveYrData)
	thetaNB <- fiveYrGLM_NB$theta
	print(paste("    theta =", thetaNB)); flush.console()
	
	perTxt <- paste(min(fiveYrPeriods[[i]]), "-", max(fiveYrPeriods[[i]]), sep="")
	fiveYrGAMs[[i]] <- myGAM(depVar, gamVars, thetaNB, writeFile=TRUE, modelName=perTxt, dataFr=fiveYrData)
}
endTime <- proc.time()
print(paste("elapsed time: ", round(endTime[3]-startTime[3]), " seconds", sep=""))
#save(fiveYrGAMs, file=paste(outDir, "fiveYrGAMs.RObject", sep=""), compress=TRUE)

