# 13 Dec 11
# 	R script that reads merged climate/conflict data & estimates regression models
#		using full violent event count data/cell for UCDP data
#		use negative binomial distribution
#
#	This file is in support of the publication:
#		OLoughlin, J., F. Witmer, A. Linke, A. Laing, A Gettelman, and J. Dudhia (2012).
#		Climate variability and conflict risk in East Africa 1990-2009.
#		Proceedings of the National Academy of Sciences.
#
#		PNAS Table S4, cols. c-d and Figs S9 c-d and S10 c-d
###############################################


# set output directory
outDir <- "C://Users/XXX/"

# load model analsys functions
source(paste(outDir, "../SharedClimateModelFunctions.R", sep=""))

# load grid-month data & define regression variables for analysis
source(paste(outDir, "../LoadOneDegGridMonthData.R", sep=""))
depVar <- "UCDP_Onsets"

modelName <- "Base"
## glm model, no splines
precipVar <- "SPI6"; tempVar <- "TI6"
glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars)
baseNB <- myGLM(depVar, glmVars, writeFile=TRUE, modelName)	# 15 minutes for UCDP events; 90 sec for onsets; 3 min for Onsets on Wilbur

## base GAM model
gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(SPI6, bs=\"",baseSmooth,"\")", sep=""), paste("s(TI6, bs=\"",baseSmooth,"\")", sep=""), controlVars)
thetaNB <- baseNB$theta		# thetaNB <- 0.08614039 for onsets
baseGAM_UCDP <- myGAM(depVar, gamVars, thetaNB, writeFile=TRUE, modelName)	# 7.5 min for UCDP; 9 min for onsets (18 min on Wilbur)
save(baseGAM_UCDP, file=paste(outDir, depVar, "baseGAM_UCDP", baseSmooth, ".Rdata", sep=""), compress=TRUE) # 12 MB


## logit model for UCDP onsets data
depVar <- "UCDP_Bin"
longData[[depVar]] <- (longData$UCDP_Onsets >= 1) * 1
longData[[paste(depVar, "SpLag_lag1", sep="")]] <- (longData[[paste("UCDP_Onsets", "SpLag_lag1", sep="")]] > 0) * 1
gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(", precipVar,", bs=\"",baseSmooth,"\")", sep=""), paste("s(",tempVar,", bs=\"",baseSmooth,"\")", sep=""), controlVars)
gamUCDPlogit <- myGAM(depVar, gamVars, thetaNB=NULL, writeFile=TRUE, "UCDP_Bin", funcForm="logit")	#  8 min; 20 min on Wilbur

